# The Spymaster Util
Common utilities and infra for The Spymaster game.

[![Unit tests](https://github.com/asaf-kali/the-spymaster-util/actions/workflows/tests.yml/badge.svg)](https://github.com/asaf-kali/the-spymaster-util/actions/workflows/tests.yml)
[![Lint](https://github.com/asaf-kali/the-spymaster-util/actions/workflows/lint.yml/badge.svg)](https://github.com/asaf-kali/the-spymaster-util/actions/workflows/lint.yml)
